#############
Storage class
#############

.. |br| raw:: html

   <br />

Storage components store commodities and thus transfer commodities between time steps.

**Storage class description:**

.. automodule:: storage
.. autoclass:: Storage
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: Storage
   :parts: 1

|

**StorageModel class description:**

.. autoclass:: StorageModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: StorageModel
   :parts: 1